@@ -2,7 +2,7 @@
 
 set -e
 
-echo "Waiting for postgres..."
+echo "Waiting for mysql..."
 
 while ! nc -z mysql 3306; do
   sleep 0.1
@@ -10,7 +10,7 @@ done
 
 echo "MySQL started"
 
-echo "Runinng the migrations against the DB"
+echo "Running the migrations against the DB"
 go run cmd/dbmigrate/main.go
 
 echo "Seeding the database"
